==> ascii_generator-1.0.0.tar.gz: ascii_generator-1.0.0/README.md <==
# ascii-generator

[![GitHub tag (latest by date)](https://img.shields.io/github/v/tag/unkokaeru/ascii-generator?label=version)](https://github.com/unkokaeru/ascii-generator)
[![Lines Of Code](https://tokei.rs/b1/github/unkokaeru/ascii-generator?category=code)](https://github.com/unkokaeru/ascii-generator)
[![Continuous Integration (CI) Tests](https://img.shields.io/github/actions/workflow/status/unkokaeru/ascii-generator/continuous_integration.yml?label=tests)](https://github.com/unkokaeru/ascii-generator)
[![GitHub last commit](https://img.shields.io/github/last-commit/unkokaeru/ascii-generator)](https://github.com/unkokaeru/ascii-generator)

Converts a PNG file to ASCII art.

- [ascii-generator](#ascii-generator)
    - [Features](#features)
    - [Installation](#installation)
    - [Usage](#usage)
    - [Documentation](#documentation)
    - [Contributing](#contributing)
    - [License](#license)

## Features

- [x] Installable via pip
- [x] Command-line interface
- [x] Interactive documentation
- [ ] PNG to ASCII conversion

## Installation

To install ascii-generator, simply run:

```bash
pip install ascii-generator
```

## Usage

After installation, you can use ascii-generator by running:

```bash
$ python3 -m ascii-generator
# or
$ ascii-generator
```

## Documentation
For more information, you can find the documentation within the [docs](./docs/index.html) directory or on the project's [GitHub Pages](https://unkokaeru.github.io/ascii-generator/).

## Contributing

Contributions are welcome! Please refer to our [CONTRIBUTING.md](./CONTRIBUTING.md) for more information.

## License

This project is licensed under the MIT License - see the [LICENSE](./LICENSE) file for details.

==> ascii_generator-1.1.0.tar.gz: ascii_generator-1.1.0/README.md <==
# ascii-generator

[![GitHub tag (latest by date)](https://img.shields.io/github/v/tag/unkokaeru/ascii-generator?label=version)](https://github.com/unkokaeru/ascii-generator)
[![Lines Of Code](https://tokei.rs/b1/github/unkokaeru/ascii-generator?category=code)](https://github.com/unkokaeru/ascii-generator)
[![Continuous Integration (CI) Tests](https://img.shields.io/github/actions/workflow/status/unkokaeru/ascii-generator/continuous_integration.yml?label=tests)](https://github.com/unkokaeru/ascii-generator)
[![GitHub last commit](https://img.shields.io/github/last-commit/unkokaeru/ascii-generator)](https://github.com/unkokaeru/ascii-generator)

Converts a PNG file to ASCII art. Mainly built just to test `untitledpythonproject`.

- [ascii-generator](#ascii-generator)
    - [Features](#features)
    - [Installation](#installation)
    - [Usage](#usage)
    - [Documentation](#documentation)
    - [Contributing](#contributing)
    - [License](#license)

## Features

- [x] Installable via pip
- [x] Command-line interface
- [x] Interactive documentation
- [ ] PNG to ASCII conversion

## Installation

To install ascii-generator, simply run:

```bash
pip install ascii-generator
```

## Usage

After installation, you can use ascii-generator by running:

```bash
$ python3 -m ascii-generator
# or
$ ascii-generator
```

## Documentation
For more information, you can find the documentation within the [docs](./docs/index.html) directory or on the project's [GitHub Pages](https://unkokaeru.github.io/ascii-generator/).

## Contributing

Contributions are welcome! Please refer to our [CONTRIBUTING.md](./CONTRIBUTING.md) for more information.

## License

This project is licensed under the MIT License - see the [LICENSE](./LICENSE) file for details.
